@@ -1,5 +1,5 @@
 from django.contrib import admin
-from .models import User, OTPCode, Session, MessageSMS, ChatRoom, MessageChat, ChatRoomPermissions, Organization
+from .models import User, OTPCode, Session, MessageSMS, ChatRoom, MessageChat, ChatRoomPermissions, Organization, Payment, Wallet
 
 
 @admin.register(User)
@@ -31,3 +31,5 @@ admin.site.register(ChatRoom)
 admin.site.register(MessageChat)
 admin.site.register(ChatRoomPermissions)
 admin.site.register(Organization)
+admin.site.register(Payment)
+admin.site.register(Wallet)
