@@ -2,5 +2,5 @@ from django.urls import re_path
 from . import consumers
 
 websocket_urlpatterns = [
-    re_path(r'ws/chat/(?P<chat_room_id>\d+)/$', consumers.ChatConsumer.as_asgi()),
-]
\ No newline at end of file
+    re_path(r'chat/(?P<chat_room_id>\d+)/$', consumers.ChatConsumer.as_asgi()),
+]
