@@ -1,6 +1,6 @@
 from rest_framework.serializers import ModelSerializer
 from django.contrib.auth.models import User
-from .models import User as mobile, OTPCode, Session, MessageSMS, ChatRoom, MessageChat
+from .models import User as mobile, OTPCode, Session, MessageSMS, ChatRoom, MessageChat, Payment
 
 # from django.contrib.auth import get_user_model
 
@@ -51,4 +51,10 @@ class MessageChatSerializer(ModelSerializer):
     class Meta:
         model = MessageChat
         fields = '__all__'
-        depth = 1
\ No newline at end of file
+        depth = 1
+
+
+class PaymentSerializer(MobileSerializer):
+    class Meta:
+        model = Payment
+        fields = '__all__'
